@@ -20,7 +20,9 @@ from .containers import (  # noqa: F401
     ContainsNoneOf,
     DictContainsAllOf,
     HasLength,
+    IsNotPresentOr,
     Len,
+    NotPresent,
 )
 from .core import Matchable, Matcher  # noqa: F401
 from .existential import (  # noqa: F401
@@ -35,4 +37,5 @@ from .existential import (  # noqa: F401
 )
 from .integration import M, Matches  # noqa: F401
 from .logical import AllOf, And, AnyOf, IsNoneOf, Not, Or, ResultsTrueFor  # noqa: F401
+from .strings import EndsWith, StartsWith  # noqa: F401
 from .types import IsInstance, OfType  # noqa: F401
